@@ -818,3 +818,45 @@ double quiskMic5Filt48Coefs[424] = {
 -0.001581622501567850, -0.001552963425946309, -0.001472389090721280, -0.001351260760102592, -0.001201670675683178,
 -0.001035675409027330, -0.000864361814542882, -0.000697354821092750, -0.000542187350923721, -0.000404455107555149,
 -0.000287398500897765, -0.000192494530734137, -0.000119178480453066, -0.000087601196745517} ;
+
+// Sample 144 kHz, pass 22.5, stop 25.5, ripple 0.1dB, atten 100 dB.  Stop 0.177083.
+double quiskFilt144D3Coefs[194] = { -0.000017362646744960, -0.000110996454883008, -0.000305662442281008,
+-0.000581062092898679, -0.000813592880911599, -0.000835736178417635, -0.000552107526238211, -0.000054292188328318,
+ 0.000387773639773515, 0.000494027000545870, 0.000199352366062691, -0.000255881206127522, -0.000485740874895228,
+-0.000275452022064688, 0.000208833549611114, 0.000531744141964012, 0.000367581824060558, -0.000175453824284145,
+-0.000607318273395854, -0.000487816655783889, 0.000132693079697097, 0.000699066404450690, 0.000638095603939989,
+-0.000070303980749569, -0.000799106348889160, -0.000818491755176836, -0.000017387631184785, 0.000902749872050692,
+ 0.001029667300547813, 0.000134959379552175, -0.001006723075110756, -0.001273440263814288, -0.000287982640712631,
+ 0.001106868403908265, 0.001551023787987609, 0.000481887570810472, -0.001198782421759553, -0.001863328908272039,
+-0.000722025795734941, 0.001278004560152671, 0.002211344243623479, 0.001013908066665751, -0.001340209298573909,
+-0.002596738345596567, -0.001363939022079807, 0.001380885370638605, 0.003022505100981749, 0.001781163375917694,
+-0.001392819236778710, -0.003490161397622442, -0.002274598703178404, 0.001368261851295833, 0.004001016216719358,
+ 0.002852992881535207, -0.001301401881125085, -0.004561084830193090, -0.003531401220247879, 0.001181711086882310,
+ 0.005175897180115789, 0.004328107542098295, -0.000995201957981096, -0.005850285719973323, -0.005262280747149780,
+ 0.000730535564202526, 0.006599333845579120, 0.006368532227413207, -0.000364276829190096, -0.007436459975443203,
+-0.007687502662736216, -0.000128323325945401, 0.008389171878714446, 0.009284846717615725, 0.000787714738678533,
+-0.009496704044210443, -0.011258777810115510, -0.001673923806614419, 0.010823740890780302, 0.013768325691894498,
+ 0.002883606625761274, -0.012483069290180011, -0.017091073428179691, -0.004588813972380848, 0.014681862153683193,
+ 0.021751575898596408, 0.007124268344056597, -0.017848070732915621, -0.028877484772780435, -0.011247057630458057,
+ 0.023018317798969463, 0.041405495608225998, 0.019112216134543804, -0.033496644504759192, -0.070110267351511241,
+-0.040261998601017132, 0.068464073221763413, 0.211997420853570540, 0.313289733368657400, 0.313289733368657400,
+ 0.211997420853570540, 0.068464073221763413, -0.040261998601017132, -0.070110267351511241, -0.033496644504759192,
+ 0.019112216134543804, 0.041405495608225998, 0.023018317798969463, -0.011247057630458057, -0.028877484772780435,
+-0.017848070732915621, 0.007124268344056597, 0.021751575898596408, 0.014681862153683193, -0.004588813972380848,
+-0.017091073428179691, -0.012483069290180011, 0.002883606625761274, 0.013768325691894498, 0.010823740890780302,
+-0.001673923806614419, -0.011258777810115510, -0.009496704044210443, 0.000787714738678533, 0.009284846717615725,
+ 0.008389171878714446, -0.000128323325945401, -0.007687502662736216, -0.007436459975443203, -0.000364276829190096,
+ 0.006368532227413207, 0.006599333845579120, 0.000730535564202526, -0.005262280747149780, -0.005850285719973323,
+-0.000995201957981096, 0.004328107542098295, 0.005175897180115789, 0.001181711086882310, -0.003531401220247879,
+-0.004561084830193090, -0.001301401881125085, 0.002852992881535207, 0.004001016216719358, 0.001368261851295833,
+-0.002274598703178404, -0.003490161397622442, -0.001392819236778710, 0.001781163375917694, 0.003022505100981749,
+ 0.001380885370638605, -0.001363939022079807, -0.002596738345596567, -0.001340209298573909, 0.001013908066665751,
+ 0.002211344243623479, 0.001278004560152671, -0.000722025795734941, -0.001863328908272039, -0.001198782421759553,
+ 0.000481887570810472, 0.001551023787987609, 0.001106868403908265, -0.000287982640712631, -0.001273440263814288,
+-0.001006723075110756, 0.000134959379552175, 0.001029667300547813, 0.000902749872050692, -0.000017387631184785,
+-0.000818491755176836, -0.000799106348889160, -0.000070303980749569, 0.000638095603939989, 0.000699066404450690,
+ 0.000132693079697097, -0.000487816655783889, -0.000607318273395854, -0.000175453824284145, 0.000367581824060558,
+ 0.000531744141964012, 0.000208833549611114, -0.000275452022064688, -0.000485740874895228, -0.000255881206127522,
+ 0.000199352366062691, 0.000494027000545870, 0.000387773639773515, -0.000054292188328318, -0.000552107526238211,
+-0.000835736178417635, -0.000813592880911599, -0.000581062092898679, -0.000305662442281008, -0.000110996454883008,
+-0.000017362646744960 };
