@@ -73,7 +73,7 @@ class Hardware(BaseHardware):
     for dec in (40, 20, 10, 8, 5, 4, 2):
       self.decimations.append(dec * 64)
     if self.conf.fft_size_multiplier == 0:
-      self.conf.fft_size_multiplier = 7		# Set size needed by VarDecim
+      self.conf.fft_size_multiplier = 6		# Set size needed by VarDecim
   def open(self):
     # Create the proper broadcast address for rx_udp_ip.
     nm = self.conf.rx_udp_ip_netmask.split('.')
@@ -293,6 +293,8 @@ class Hardware(BaseHardware):
     self.rx_control = dec // 64 - 1		# Second stage decimation less one
     self.NewUdpStatus()
     return int(float(self.conf.rx_udp_clock) / dec + 0.5)
+  def VarDecimRange(self):
+    return (48000, 960000)
   def NewUdpStatus(self, do_tx=False):
     s = "St"
     s = s + struct.pack("<L", self.rx_phase)
