@@ -1,7 +1,7 @@
 #include <Python.h>
 #include <stdlib.h>
 #include <math.h>
-#include <sys/timeb.h>
+#include <sys/time.h>
 #include <complex.h>
 #include <fftw3.h>
 #include "quisk.h"
@@ -15,6 +15,7 @@ static int mic_cleanup = 0;		// must clean up winsock
 #else
 #include <sys/socket.h>
 #include <arpa/inet.h>
+#include <netinet/in.h>
 #define		INVALID_SOCKET	-1
 #endif
 
@@ -37,10 +38,10 @@ double quisk_mic_clip;
 #define DECIM_8000	1
 
 // These are external:
-int mic_max_display;			// display value of maximum microphone signal level 0 to 2**15 - 1
+int mic_max_display;				// display value of maximum microphone signal level 0 to 2**15 - 1
+int quiskSpotLevel = 0;				// 0 for no spotting; else the level 10 to 1000
 
 static int mic_socket = INVALID_SOCKET;	// send microphone samples to a socket
-static int spotLevel = 0;				// 0 for no spotting; else the level 10 to 1000
 static double mic_min_level = 0.10;		// Mic levels below this are noise and are ignored
 
 static int mic_level;			// maximum microphone signal level for display
@@ -112,7 +113,7 @@ static void open_wav(void)
 	}
 }
 
-static void get_wav(complex * buffer, int count)
+static void get_wav(complex double * buffer, int count)
 {
 	// Put transmit audio samples from a file into buffer.
 	// The sample rate must equal quisk_sound_state.mic_sample_rate.
@@ -134,12 +135,12 @@ static void get_wav(complex * buffer, int count)
 #endif
 
 #if USE_GET_SIN
-static void get_sin(complex * cSamples, int count)
+static void get_sin(complex double * cSamples, int count)
 {	// replace mic samples with a sin wave
 	int i;
 	double freq;
-	complex phase1;		// Phase increment
-	static complex vector1 = CLIP32 / 2;
+	complex double phase1;		// Phase increment
+	static complex double vector1 = CLIP32 / 2;
 
 	// Use the sidetone slider 0 to 1000 to set frequency
 	//freq = (quisk_sidetoneCtrl - 500) / 1000.0 * MIC_OUT_RATE;
@@ -163,12 +164,12 @@ static void get_sin(complex * cSamples, int count)
 #endif
 
 #if USE_2TONE
-static void get_2tone(complex * cSamples, int count)
+static void get_2tone(complex double * cSamples, int count)
 {	// replace mic samples
 	int i;
-	static complex phase1=0, phase2;		// Phase increment
-	static complex vector1;
-	static complex vector2;
+	static complex double phase1=0, phase2;		// Phase increment
+	static complex double vector1;
+	static complex double vector2;
 
 	if (phase1 == 0) {		// initialize
 		phase1 = cexp((I * 2.0 * M_PI * IMD_TONE_1) / quisk_sound_state.mic_sample_rate);
@@ -184,10 +185,10 @@ static void get_2tone(complex * cSamples, int count)
 }
 #endif
 
-static double CcmPeak(double * dsamples, complex * csamples, int count)
+static double CcmPeak(double * dsamples, complex double * csamples, int count)
 {
 	int i, j;
-	complex csample;
+	complex double csample;
 	double dtmp, dsample, newlevel, oldlevel;
 	static double out_short, out_long;
 	static struct Ccmpr {
@@ -196,7 +197,7 @@ static double CcmPeak(double * dsamples, complex * csamples, int count)
 		double themax;
 		double level;
 		double * d_samp;
-		complex * c_samp;
+		complex double * c_samp;
 		double * levl;
 	} dat = {0};
 
@@ -206,7 +207,7 @@ static double CcmPeak(double * dsamples, complex * csamples, int count)
 		dat.themax = 1.0;					// maximum level in the buffer
 		dat.level = 1.0;					// current output level
 		dat.d_samp = (double *) malloc(dat.buf_size * sizeof(double));		// buffer for double samples
-		dat.c_samp = (complex *) malloc(dat.buf_size * sizeof(complex));	// buffer for complex samples
+		dat.c_samp = (complex double *) malloc(dat.buf_size * sizeof(complex double));	// buffer for complex samples
 		dat.levl = (double *) malloc(dat.buf_size * sizeof(double));		// magnitude of the samples
 		for (i = 0; i < dat.buf_size; i++) {
 			dat.d_samp[i] = 0;
@@ -258,18 +259,18 @@ static double CcmPeak(double * dsamples, complex * csamples, int count)
 	return dat.level;
 }
 
-static int tx_filter(complex * filtered, int count)
+static int tx_filter(complex double * filtered, int count)
 {	// Input samples are creal(filtered), output is filtered.  The input rate must be 8000 or 48000 sps.
 	int i, is_ssb;
 	int sample_rate = 8000;
 	double dsample, dtmp, magn;
-	complex csample;
+	complex double csample;
 	static double inMax=0.3;
 	static double x_1=0;
 	static double aaa, bbb, ccc, Xmin, Xmax, Ymax;
-    static int samples_size = 0;
-    static double * dsamples = NULL;
-	static complex * csamples = NULL;
+	static int samples_size = 0;
+	static double * dsamples = NULL;
+	static complex double * csamples = NULL;
 	static double time_long, time_short;
 	static struct quisk_dFilter filtDecim, dfiltInterp;
 	static struct quisk_dFilter filtAudio1, filtAudio2, dfiltAudio3;
@@ -319,7 +320,7 @@ static int tx_filter(complex * filtered, int count)
         if (csamples)
             free(csamples);
         dsamples = (double *)malloc(samples_size * sizeof(double));
-        csamples = (complex *)malloc(samples_size * sizeof(complex));
+        csamples = (complex double *)malloc(samples_size * sizeof(complex double));
     }
 	// copy to dsamples[], normalize to +/- 1.0
 	for (i = 0; i < count; i++)
@@ -498,12 +499,12 @@ static int tx_filter(complex * filtered, int count)
 	return count;
 }
 
-static int tx_filter_digital(complex * filtered, int count, double volume)
+static int tx_filter_digital(complex double * filtered, int count, double volume)
 {	// Input samples are creal(filtered), output is filtered.
 	// This filter has minimal processing and is used for digital modes.
 	int i;
 	double dsample, amplitude;
-	complex csample;
+	complex double csample;
 
 	static struct quisk_dFilter filter1;
 #if DEBUG_IO
@@ -559,7 +560,7 @@ PyObject * quisk_get_tx_filter(PyObject * self, PyObject * args)
 	int i, j, k;
 	int freq, time;
 	PyObject * tuple2;
-	complex cx;
+	complex double cx;
 	double scale;
 	double * average, * fft_window, * bufI, * bufQ;
 	fftw_complex * samples, * pt;		// complex data for fft
@@ -646,7 +647,7 @@ PyObject * quisk_get_tx_filter(PyObject * self, PyObject * args)
 // udp_iq has an initial zero followed by the I/Q samples.
 // The initial zero is sent iff align4 == 1.
 
-static void transmit_udp(complex * cSamples, int count)
+static void transmit_udp(complex double * cSamples, int count)
 {	// Send count samples.  Each sample is sent as two shorts (4 bytes) of I/Q data.
 	// Transmission is delayed until a whole block of data is available.
 	int i, sent;
@@ -675,7 +676,7 @@ static void transmit_udp(complex * cSamples, int count)
 	}
 }
 
-static void transmit_mic_carrier(complex * cSamples, int count, double level)
+static void transmit_mic_carrier(complex double * cSamples, int count, double level)
 {	// send a CW carrier instead of mic samples
 	int i;
 
@@ -684,13 +685,13 @@ static void transmit_mic_carrier(complex * cSamples, int count, double level)
 	transmit_udp(cSamples, count);
 }
 
-static void transmit_mic_imd(complex * cSamples, int count, double level)
+static void transmit_mic_imd(complex double * cSamples, int count, double level)
 {	// send a 2-tone test signal instead of mic samples
 	int i;
-	complex v;
-	static complex phase1=0, phase2;		// Phase increment
-	static complex vector1;
-	static complex vector2;
+	complex double v;
+	static complex double phase1=0, phase2;		// Phase increment
+	static complex double vector1;
+	static complex double vector2;
 
 	if (phase1 == 0) {		// initialize
 		phase1 = cexp((I * 2.0 * M_PI * IMD_TONE_1) / MIC_OUT_RATE);
@@ -707,7 +708,7 @@ static void transmit_mic_imd(complex * cSamples, int count, double level)
 	transmit_udp(cSamples, count);
 }
 
-int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
+int quisk_process_microphone(int mic_sample_rate, complex double * cSamples, int count)
 {
 	int i, sample, maximum, interp, mic_interp;
 	double d;
@@ -721,18 +722,18 @@ int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
 	// Measure soundcard actual sample rate
 	static time_t seconds = 0;
 	static int total = 0;
-	struct timeb tb;
+	struct timeval tb;
 	static double dtime;
 
-	ftime(&tb);
+	gettimeofday(&tb);
 	total += count;
 	if (seconds == 0) {
-		seconds = tb.time;
-		dtime = tb.time + .001 * tb.millitm;
+		seconds = tb.tv_sec;
+		dtime = tb.tv_sec + 0.000001 * tb.tv_usec;
 	}		
-	else if (tb.time - seconds > 4) {
-		printf("Mic soundcard rate %.3f\n", total / (tb.time + .001 * tb.millitm - dtime));
-		seconds = tb.time;
+	else if (tb.tv_sec - seconds > 4) {
+		printf("Mic soundcard rate %.3f\n", total / (tb.tv_sec + .000001 * tb.tv_usec - dtime));
+		seconds = tb.tv_sec;
 		printf("backlog %d, count %d\n", backlog, count);
 	}
 #endif
@@ -792,13 +793,13 @@ int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
 				count = tx_filter_digital(cSamples, count, 0.9);	// filter samples, minimal processing
 				transmit_udp(cSamples, count);
 			}
-			else if (spotLevel == 0) {
+			else if (quiskSpotLevel == 0) {
 				count = tx_filter(cSamples, count);		// filter samples
 				transmit_udp(cSamples, count);
 			}
 			else {
 				count *= interp;
-				transmit_mic_carrier(cSamples, count, spotLevel / 1000.0);
+				transmit_mic_carrier(cSamples, count, quiskSpotLevel / 1000.0);
 			}
 			break;
 		case 4:		// AM
@@ -819,13 +820,13 @@ int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
 		case 7:		// digital modes
 		case 8:
 		case 9:
-			if (spotLevel == 0) {
+			if (quiskSpotLevel == 0) {
 				count = tx_filter_digital(cSamples, count, 1.0);	// filter samples, minimal processing
 				transmit_udp(cSamples, count);
 			}
 			else {
 				count *= interp;
-				transmit_mic_carrier(cSamples, count, spotLevel / 1000.0);
+				transmit_mic_carrier(cSamples, count, quiskSpotLevel / 1000.0);
 			}
   			break;
 		case 10:	// transmit IMD 2-tone test
@@ -975,18 +976,9 @@ void quisk_set_tx_mode(void)	// called when the mode rxMode is changed
 {
 	tx_filter(NULL, 0);
 	tx_filter_digital(NULL, 0, 0.0);
+	transmit_udp(NULL, 0);
 #ifdef TEST_TX_WAV_FILE
 	if (!wavFp)			// convenient place to open file
 		open_wav();
 #endif
 }
-
-PyObject * quisk_set_spot_level(PyObject * self, PyObject * args)
-{
-	if (!PyArg_ParseTuple (args, "i", &spotLevel))
-		return NULL;
-	if (spotLevel == 0)
-		transmit_udp(NULL, 0);		// initialization
-	Py_INCREF (Py_None);
-	return Py_None;
-}
