@@ -31,6 +31,8 @@ class Hardware(BaseHw):
       self.lpfilter.SetTxFreq(tx_freq)
       self.hpfilter.SetTxFreq(tx_freq)
   def ChangeFrequency(self, tx_freq, vfo_freq, source='', band='', event=None):
+    if source == 'MouseBtn1' and self.application.mode in ('LSB', 'USB', 'AM', 'FM'):
+      tx_freq = (tx_freq + 500) // 1000 * 1000
     self.ChangeFilterFrequency(tx_freq)
     return BaseHw.ChangeFrequency(self, tx_freq, vfo_freq, source, band, event)
   def ChangeBand(self, band):
