@@ -14,7 +14,7 @@ gatewayTime = 0			# time of last gateway command
 gatewayLimit = 0.2	# minimum time between gateway commands
 
 class LowPassFilter:	# Control my low pass filter box
-  address = ('192.168.2.194', 0x3A00 + 39)
+  address = ('192.168.1.194', 0x3A00 + 39)
   # Filters are numbered 1 thru 8 for bands: 80, 15, 60, 40, 30, 20, 17, short
   lpfnum = (1, 1, 1, 1, 1, 3,	# frequency 0 thru 5 MHz
                4, 4, 5, 5, 5,	# 6 thru 10
@@ -41,7 +41,7 @@ class LowPassFilter:	# Control my low pass filter box
       return	# Ignore small tuning changes
     self.old_tx_freq = tx_freq
     try:		# Look up filter number based on MHz
-      num = self.lpfnum[tx_freq / 1000000]
+      num = self.lpfnum[tx_freq // 1000000]
     except IndexError:
       num = 8
     self.want_data =  chr(num)
@@ -70,7 +70,7 @@ class LowPassFilter:	# Control my low pass filter box
         pass
 
 class HighPassFilter:	# Control my high pass filter box
-  address = ('192.168.2.194', 0x3A00 + 21)
+  address = ('192.168.1.194', 0x3A00 + 21)
   def __init__(self, app, conf):
     self.application = app	# Application instance (to provide attributes)
     self.conf = conf		# Config file module
@@ -194,7 +194,7 @@ class HighPassFilter:	# Control my high pass filter box
         pass
 
 class AntennaControl:	# Control my KI8BV dipole
-  AntCtrlAddress = ('192.168.2.194', 0x3A00 + 33)
+  AntCtrlAddress = ('192.168.1.194', 0x3A00 + 33)
   def __init__(self, app, conf):
     self.application = app	# Application instance (to provide attributes)
     self.conf = conf		# Config file module
@@ -237,7 +237,7 @@ class AntennaControl:	# Control my KI8BV dipole
         pass
 
 class AntennaTuner:     # Control my homebrew antenna tuner and my KI8BV dipole
-  address = ('192.168.2.194', 0x3A00 + 47)
+  address = ('192.168.1.194', 0x3A00 + 47)
   def __init__(self, app, conf):
     self.application = app	# Application instance (to provide attributes)
     self.conf = conf		# Config file module
@@ -316,7 +316,7 @@ class AntennaTuner:     # Control my homebrew antenna tuner and my KI8BV dipole
       return
     if self.disable_freq_control:
       return
-    freq = (tx_freq + 5000) / 10000 * 10000		# rounded frequency
+    freq = (tx_freq + 5000) // 10000 * 10000		# rounded frequency
     try:
       newL, newC, newH = self.TunerLC[freq]
     except KeyError:
