@@ -23,9 +23,23 @@
 // 3 == Copy transmit audio to the output.
 #define TEST_AUDIO	0
 
+
+// Pulseaudio support added by Philip G. Lee.  Many thanks!
+/*!
+ * \brief Specifies which driver a \c sound_dev is opened with
+ */
+typedef enum dev_driver{
+   DEV_DRIVER_NONE = 0,
+   DEV_DRIVER_PORTAUDIO,
+   DEV_DRIVER_ALSA,
+   DEV_DRIVER_PULSEAUDIO
+} dev_driver_t;
+
 struct sound_dev {				// data for sound capture or playback device
 	char name[QUISK_SC_SIZE];	// string name of device
+	char stream_description[QUISK_SC_SIZE]; // Short description of device/stream
 	void * handle;				// Handle of open device, or NULL
+	dev_driver_t driver;		// Which audio driver the device is using
 	void * buffer;				// Handle of buffer for device
 	int portaudio_index;		// index of portaudio device, or -1
 	int doAmplPhase;			// Amplitude and Phase corrections
@@ -40,7 +54,10 @@ struct sound_dev {				// data for sound capture or playback device
 	int channel_Q;
 	int channel_Delay;			// Delay this channel by one sample; -1 for no delay, else channel_I or _Q
 	int overrange;				// Count for ADC overrange (clip) for device
-	int read_frames;			// number of frames for read request
+   // Number of frames for a read request.
+   // If 0, the read should be non-blocking and read all available
+   // frames.
+	int read_frames;
 	int latency_frames;			// desired latency in audio play samples
 	int play_buf_size;			// size of playback buffer in samples
 	int use_float;				// DirectX: Use IEEE floating point
@@ -55,7 +72,7 @@ struct sound_dev {				// data for sound capture or playback device
 	unsigned int rate_max;
 	unsigned int chan_min;		// min and max available number of channels
 	unsigned int chan_max;
-	complex dc_remove;			// filter to remove DC from samples
+	complex double dc_remove;			// filter to remove DC from samples
 	double save_sample;			// Used to delay the I or Q sample
 	char msg1[QUISK_SC_SIZE];	// string for information message
 } ;
@@ -102,6 +119,7 @@ extern enum quisk_rec_state quisk_record_state;
 
 extern struct sound_conf quisk_sound_state, * pt_quisk_sound_state;
 extern int mic_max_display;		// display value of maximum microphone signal level
+extern int quiskSpotLevel;		// 0 for no spotting; else the level 10 to 1000
 extern int data_width;
 extern int quisk_using_udp;	// is a UDP port used for capture (0 or 1)?
 extern int rxMode;				// mode CWL, USB, etc.
@@ -132,41 +150,47 @@ extern PyObject * quisk_is_vox(PyObject *, PyObject *);
 // radio data samples.
 typedef void (* ty_sample_start)(void);
 typedef void (* ty_sample_stop)(void);
-typedef int  (* ty_sample_read)(complex *);
+typedef int  (* ty_sample_read)(complex double *);
 
 void quisk_open_sound(void);
 void quisk_close_sound(void);
-int quisk_process_samples(complex *, int);
+int quisk_process_samples(complex double *, int);
 void quisk_play_samples(double *, int);
 void quisk_play_zeros(int);
 void quisk_start_sound(void);
 int quisk_get_overrange(void);
 void quisk_mixer_set(char *, int, PyObject *, char *, int);
 int quisk_read_sound(void);
-int quisk_process_microphone(int, complex *, int);
+int quisk_process_microphone(int, complex double *, int);
 void quisk_open_mic(void);
 void quisk_close_mic(void);
 int quisk_open_key(const char *);
 void quisk_close_key(void);
 int quisk_is_key_down(void);
 void quisk_set_key_down(int);
-int quisk_read_rx_udp(complex *);
 void quisk_set_tx_mode(void);
 void ptimer(int);
-int quisk_extern_demod(complex *, int, double);
-void quisk_tmp_microphone(complex *, int);
-void quisk_tmp_record(complex * , int, double);
+int quisk_extern_demod(complex double *, int, double);
+void quisk_tmp_microphone(complex double *, int);
+void quisk_tmp_record(complex double * , int, double);
 
-int  quisk_read_alsa(struct sound_dev *, complex *);
-void quisk_play_alsa(struct sound_dev *, int, complex *, int, double);
+// Driver function definitions=================================================
+int  quisk_read_alsa(struct sound_dev *, complex double *);
+void quisk_play_alsa(struct sound_dev *, int, complex double *, int, double);
 void quisk_start_sound_alsa(struct sound_dev **, struct sound_dev **);
 void quisk_close_sound_alsa(struct sound_dev **, struct sound_dev **);
 
-int  quisk_read_portaudio(struct sound_dev *, complex *);
-void quisk_play_portaudio(struct sound_dev *, int, complex *, int, double);
+int  quisk_read_portaudio(struct sound_dev *, complex double *);
+void quisk_play_portaudio(struct sound_dev *, int, complex double *, int, double);
 void quisk_start_sound_portaudio(struct sound_dev **, struct sound_dev **);
 void quisk_close_sound_portaudio(void);
 
+int  quisk_read_pulseaudio(struct sound_dev *, complex double *);
+void quisk_play_pulseaudio(struct sound_dev *, int, complex double *, int, double);
+void quisk_start_sound_pulseaudio(struct sound_dev **, struct sound_dev **);
+void quisk_close_sound_pulseaudio(struct sound_dev **, struct sound_dev **);
+//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+
 /*
 Functions defined below this point are available for export to other extension modules using the
 standard Python CObject or Capsule interface.  See the documentation in import_quisk_api.c.  Note
