@@ -173,6 +173,13 @@ display_fraction = 1.00
 # If you want to transmit recorded sound, then mic_sample_rate must equal playback_rate and both must be 48000.
 max_record_minutes = 1.00
 
+# Quisk can save recorded sound and samples to files.  There is a button on the Config/Config screen
+# to set the file names.  You can set the initial names with these variables:
+file_name_audio = ""
+#file_name_audio = "/home/jim/tmp/qaudio.wav"
+file_name_samples = ""
+#file_name_samples = "C:/tmp/qsamples.wav"
+
 # Thanks to Steve Murphy, KB8RWQ for the patch adding additional color control.
 # Thanks to Christof, DJ4CM for the patch adding additional color control. 
 # Define colors used by all widgets in wxPython colour format:
@@ -279,6 +286,11 @@ digipanWaterfallPalette = (
 #name_of_sound_capt = "plughw:1"
 #name_of_sound_capt = "default"
 
+# Pulseaudio support added by Philip G. Lee.  Many thanks!
+# For PulseAudio support, use the name "pulse" and connect the streams
+# to your hardware devices using a program like pavucontrol
+#name_of_sound_capt = "pulse"
+
 # Normally you would capture and play on the same soundcard to avoid problems with the
 # two clocks running at slightly different rates.  But you can define name_of_sound_play
 # to play back on a different device.  Define this as the empty string "" to turn off
@@ -694,8 +706,12 @@ BandEdge = {
 	'30' :(10100000, 10150000),	'20' :(14000000, 14350000),	
 	'17' :(18068000, 18168000), '15' :(21000000, 21450000),
 	'12' :(24890000, 24990000),	'10' :(28000000, 29700000),
-	'6'  :(50000000, 54000000),
-	'2'  :(144000000, 148000000),
+	'6'     :(  50000000,   54000000),
+	'2'     :( 144000000,  148000000),
+    '1.25'  :( 222000000,  225000000),
+    '70cm'  :( 420000000,  450000000),
+    '33cm'  :( 902000000,  928000000),
+    '23cm'  :(1240000000, 1300000000),
 	}
 
 # For each band, this dictionary gives the initial center frequency, tuning
@@ -705,10 +721,13 @@ BandEdge = {
 bandState = {'Audio':(0, 0, 'LSB'),
       '160':( 1890000, -10000, 'LSB'), '80' :( 3660000, -10000, 'LSB'),
       '60' :( 5370000,   1500, 'USB'), '40' :( 7180000, -5000, 'LSB'),  '30':(10120000, -10000, 'CWL'),
-      '20' :(14200000, -10000, 'USB'), '17' :(18120000,  10000, 'USB'), '15':(21250000, -10000, 'USB'),
-      '12' :(24940000,  10000, 'USB'), '10' :(28400000, -10000, 'USB'),
-      'Time':( 5000000, 0, 'AM'), '6' :(50040000,  10000, 'USB'),
-		}
+      'Time':( 5000000, 0, 'AM')}
+for band, (f1, f2) in BandEdge.items():
+  if f1 > 13500000:
+    f = (f1 + f2) / 2
+    f = (f + 5000) / 10000
+    f *= 10000
+    bandState[band] = (f, 10000, 'USB')
 
 # For the Time band, this is the center frequency, tuning frequency and mode:
 bandTime = [
@@ -761,6 +780,9 @@ else:
 # too small you will get many fft errors.  You can specify fft_size_multiplier,
 # or enter a large number (use 9999) to maximize it, or enter zero to let
 # quisk calculate it for you.  Look for fft_size_multiplier in quisk.py.
+# Your fft_size_multiplier should have many small factors.  Avoid 7 and 13, and
+# use 8 or 12 instead.
+#
 # If your hardware can change the decimation, there are further compilcations.
 # The FFT size is fixed, and only the average count can change to adjust the
 # refresh rate.
