@@ -40,7 +40,7 @@ class FrequencyDisplay(wx.lib.stattext.GenStaticText):
     self.SetSizeHints(w, h, w * 5, h)
     self.height = h
     self.points = points
-    border = self.border = (height - self.height) / 2
+    border = self.border = (height - self.height) // 2
     self.height_and_border = h + border * 2
     self.SetBackgroundColour(conf.color_freq)
     self.SetForegroundColour(conf.color_freq_txt)
@@ -117,14 +117,15 @@ class FrequencyDisplay(wx.lib.stattext.GenStaticText):
   
 
 class SliderBoxH:
-  """A horizontal control with a slider and text with a value.  The text must have a %d if display is True."""
-  def __init__(self, parent, text, init, themin, themax, handler, display, pos, width):
+  """A horizontal control with a slider and text with a value.  The text must have a %d or %f if display is True."""
+  def __init__(self, parent, text, init, themin, themax, handler, display, pos, width, scale=1):
     self.text = text
     self.handler = handler
     self.display = display
+    self.scale = scale
     if display:		# Display the slider value
-      t1 = self.text % themin
-      t2 = self.text % themax
+      t1 = self.text % (themin * scale)
+      t2 = self.text % (themax * scale)
       if len(t1) > len(t2):		# set text size to the largest
         t = t1
       else:
@@ -141,6 +142,7 @@ class SliderBoxH:
       w2, h2 = self.text_ctrl.GetSize()
       self.slider = wx.Slider(parent, -1, init, themin, themax, (pos[0] + w2, pos[1]), (width - w2, h2))
     self.slider.Bind(wx.EVT_SCROLL, self.OnScroll)
+    self.text_ctrl.SetForegroundColour(parent.GetForegroundColour())
     self.OnScroll()
   def OnScroll(self, event=None):
     if event:
@@ -148,7 +150,7 @@ class SliderBoxH:
       if self.handler:
         self.handler(event)
     if self.display:
-      t = self.text % self.slider.GetValue()
+      t = self.text % (self.slider.GetValue() * self.scale)
     else:
       t = self.text
     self.text_ctrl.SetLabel(t)
@@ -193,6 +195,7 @@ class SliderBoxV(wx.BoxSizer):
       self.text_ctrl = wx.StaticText(parent, -1, text)
       w2, h2 = self.text_ctrl.GetSize()	# Measure size with text
       self.width = max(w2, sw)
+    self.text_ctrl.SetForegroundColour(parent.GetForegroundColour())
     self.Add(self.text_ctrl, 0, wx.ALIGN_CENTER)
     self.Add(self.slider, 1, wx.ALIGN_CENTER)
   def Change(self, event):
@@ -218,6 +221,7 @@ class _QuiskText1(wx.lib.stattext.GenStaticText):
     self.size_text = size_text
     self.pen = wx.Pen(conf.color_btn, 2)
     self.brush = wx.Brush(conf.color_freq)
+    self.SetForegroundColour(conf.color_freq_txt)
     self.SetSizeHints(-1, height, -1, height)
   def _MeasureFont(self, dc, width, height):
     # Set decreasing point size until size_text fits in the space available
@@ -253,7 +257,7 @@ class _QuiskText1(wx.lib.stattext.GenStaticText):
       dc.SetTextForeground(wx.SystemSettings.GetColour(wx.SYS_COLOUR_GRAYTEXT))
     style = self.GetWindowStyleFlag()
     w, h = dc.GetTextExtent(label)
-    y = (height - h) / 2
+    y = (height - h) // 2
     if y < 0:
       y = 0
     if style & wx.ALIGN_RIGHT:
@@ -298,7 +302,7 @@ class QuiskButtons:
       w, h = self.GetTextExtent("OK")
       self.Disable()	# create a size for null text, but Disable()
     w += self.button_bezel * 2 + self.GetCharWidth()
-    h = h * 12 / 10
+    h = h * 12 // 10
     h += self.button_bezel * 2
     self.SetSizeHints(w, h, w * 6, h, 1, 1)
   def DrawLabel(self, dc, width, height, dx=0, dy=0):	# Override to change Disable text color
@@ -315,7 +319,7 @@ class QuiskButtons:
             dc.SetTextForeground(conf.color_enable)
         else:
           dc.SetTextForeground(conf.color_disable)
-        dc.DrawText(part, (width-tw)/2+dx, (height-th)/2+dy)
+        dc.DrawText(part, (width-tw)//2+dx, (height-th)//2+dy)
         dx += dc.GetTextExtent(part)[0]
   def OnKeyDown(self, event):
     pass
@@ -513,7 +517,7 @@ class QuiskFilterButton(QuiskCheckbutton):
 
 class QSliderButtonWindow(wx.Frame):
   """Create a window with controls for the button"""
-  def __init__(self, button):
+  def __init__(self, button, value):
     self.button = button
     x, y = button.GetPositionTuple()
     x, y = button.GetParent().ClientToScreenXY(x, y)
@@ -528,20 +532,15 @@ class QSliderButtonWindow(wx.Frame):
       wx.FRAME_TOOL_WINDOW|wx.FRAME_FLOAT_ON_PARENT|wx.CLOSE_BOX|wx.CAPTION|wx.SYSTEM_MENU)
     self.SetBackgroundColour(conf.color_freq)
     self.Bind(wx.EVT_CLOSE, self.OnClose)
-    self.slider = wx.Slider(self, -1, self.button.slider_value,
+    self.slider = wx.Slider(self, -1, value,
              self.button.slider_min, self.button.slider_max,
              (0, 0), (w/2, height), wx.SL_VERTICAL)
-    self.slider.Bind(wx.EVT_SCROLL, self.OnSlider)
+    self.slider.Bind(wx.EVT_SCROLL, self.button.OnSlider)
     self.Show()
     self.slider.SetFocus()
-  def OnSlider(self, event):
-    self.button.slider_value = self.slider.GetValue()
-    self.button.SetValue(self.button.GetValue(), True)
-    self.button.SetLabel()
   def OnClose(self, event):
     self.button.adjust = None
     self.Destroy()
-    self.button.SetLabel()
 
 class QuiskSliderButton(QuiskCheckbutton):
   """An adjustable check button; right-click to adjust."""
@@ -550,24 +549,56 @@ class QuiskSliderButton(QuiskCheckbutton):
     if color is None:
       color = conf.color_adjust_btn
     self.text = text
-    self.slider_value = slider_value
+    self.dual = False						# separate values for button up or down
+    self.slider_value = slider_value		# value for not dual
+    self.slider_value_off = slider_value	# value for dual and button up
+    self.slider_value_on = slider_value		# value for dual and button down
     self.slider_min = slider_min
     self.slider_max = slider_max
     QuiskCheckbutton.__init__(self, parent, command, text, color)
     self.Bind(wx.EVT_RIGHT_DOWN, self.OnRightDown)
     self.adjust = None
+  def SetDual(self, dual):		# dual means separate slider values for on and off
+    self.dual = dual
+    if self.adjust:
+      self.adjust.Destroy()
+      self.adjust = None
   def OnRightDown(self, event):
-    self.OnButton(event)
     if self.adjust:
       self.adjust.Destroy()
       self.adjust = None
     else:
-      self.adjust = QSliderButtonWindow(self)
+      if not self.dual:
+        value = self.slider_value
+      elif self.GetValue():
+        value = self.slider_value_on
+      else:
+        value = self.slider_value_off
+      self.adjust = QSliderButtonWindow(self, value)
   def SetLabel(self, text=None):
     if text is not None:
       QuiskCheckbutton.SetLabel(self, text)
-  def SetSlider(self, value):
-    self.slider_value = value
+  def SetSlider(self, value=None, value_off=None, value_on=None):
+    if value is not None:
+      self.slider_value = value
+    if value_off is not None:
+      self.slider_value_off = value_off
+    if value_on is not None:
+      self.slider_value_on = value_on
+  def OnSlider(self, event):
+    value = event.GetEventObject().GetValue()
+    if not self.dual:
+      self.slider_value = value
+    elif self.GetValue():
+      self.slider_value_on = value
+    else:
+      self.slider_value_off = value
+    self.SetValue(self.GetValue(), True)
+  def OnButton(self, event):
+    if self.adjust:
+      self.adjust.Destroy()
+      self.adjust = None
+    QuiskCheckbutton.OnButton(self, event)
 
 class QuiskSpotButton(QuiskSliderButton):
   def SetLabel(self, text=None):
