@@ -246,7 +246,7 @@ static void set_item(	// host command to set a control item
 // The ft245 driver does not have a circular buffer for input; bytes are just appended
 // to the buffer.  When all bytes are read and the buffer goes empty, the pointers are reset to zero.
 // Be sure to empty out the ft245 frequently so its buffer does not overflow.
-static int sdr_recv(complex * samp, int sampsize)
+static int sdr_recv(complex double * samp, int sampsize)
 {		// Read all data from the SDR-IQ and process it.
 		// Return the number >= 0 of I/Q data samples that are available in samp.
 	int k, res, item, navail, nSamples;
@@ -748,7 +748,7 @@ static void quisk_start_sdriq(void)
 static void quisk_stop_sdriq(void)
 {
 	int msec;
-	complex samples[2048];
+	complex double samples[2048];
 
 	for (msec = 0; msec < 1001; msec++) {
 		if (msec % 100 == 0)
@@ -767,7 +767,7 @@ static void quisk_stop_sdriq(void)
 }
 
 // Called in a loop to read samples; called from the sound thread.
-static int quisk_read_sdriq(complex * cSamples)
+static int quisk_read_sdriq(complex double * cSamples)
 {
 	int length;
 
