@@ -111,7 +111,8 @@ class Hardware(BaseHardware):
     # band is a string: "60", "40", "WWV", etc.
     pass
   def OnSpot(self, level):
-    pass
+    if self.key_thread:
+      self.key_thread.OnSpot(level)
   def HeartBeat(self):	# Called at about 10 Hz by the main
     pass
   def OnButtonPTT(self, event=None):
@@ -217,6 +218,7 @@ class KeyThread(threading.Thread):
     self.poll_secs = poll_secs
     self.key_hang_time = key_hang_time
     self.ptt_button = 0
+    self.spot_level = 0
     self.currently_in_tx = 0
     self.is_cw = False
     self.key_timer = 0
@@ -233,14 +235,14 @@ class KeyThread(threading.Thread):
           if DEBUG: traceback.print_exc()
         else:
           # bit 0x20 is the tip, bit 0x02 is the ring (ring not used)
-          if ret[0] & 0x20:		# Tip: key is up
-            QS.set_key_down(0)
-            if self.is_transmit and time.time() - self.key_timer > self.key_hang_time:
-              self.is_transmit = 0
-          else:			# key is down
+          if self.spot_level or ret[0] & 0x20 == 0:		# Tip: key is down
             QS.set_key_down(1)
             self.is_transmit = 1
             self.key_timer = time.time()
+          else:			# key is up
+            QS.set_key_down(0)
+            if self.is_transmit and time.time() - self.key_timer > self.key_hang_time:
+              self.is_transmit = 0
           if self.is_transmit != self.currently_in_tx:
             try:
               self.usb_dev.ctrl_transfer(IN, 0x50, self.is_transmit, 0, 3)
@@ -265,5 +267,7 @@ class KeyThread(threading.Thread):
     self.doQuit.set()
   def OnPTT(self, ptt):
     self.ptt_button = ptt
+  def OnSpot(self, level):
+    self.spot_level = level
   def IsCW(self, is_cw):
     self.is_cw = is_cw
