@@ -51,7 +51,7 @@ static ty_sample_start pt_sample_start;
 static ty_sample_stop  pt_sample_stop;
 static ty_sample_read  pt_sample_read;
 
-static complex cSamples[SAMP_BUFFER_SIZE];			// Complex buffer for samples
+static complex double cSamples[SAMP_BUFFER_SIZE];			// Complex buffer for samples
 
 void ptimer(int counts)	// used for debugging
 {	// print the number of counts per second
@@ -100,7 +100,7 @@ static void delay_sample (struct sound_dev * dev, double * dSamp, int nSamples)
 	*first = d;
 }
 
-static void correct_sample (struct sound_dev * dev, complex * cSamples, int nSamples)
+static void correct_sample (struct sound_dev * dev, complex double * cSamples, int nSamples)
 {	// Correct the amplitude and phase
 	int i;
 	double re, im;
@@ -116,7 +116,7 @@ static void correct_sample (struct sound_dev * dev, complex * cSamples, int nSam
 	}
 }
 
-static int record_audio(complex * cSamples, int nSamples)
+static int record_audio(complex double * cSamples, int nSamples)
 {  // Record the speaker audio to a WAV file, PCM, 16 bits, one channel
 	static FILE * fp = NULL;	// TODO: correct for big-endian byte order
 	static unsigned int samples=0, remain=0;
@@ -188,7 +188,7 @@ static int record_audio(complex * cSamples, int nSamples)
 	return 1;
 }
 
-static int record_samples(complex * cSamples, int nSamples)
+static int record_samples(complex double * cSamples, int nSamples)
 {  // Record the samples to a WAV file, two float samples I/Q
 	static FILE * fp = NULL;	// TODO: correct for big-endian byte order
 	static unsigned int samples=0, remain=0;
@@ -279,33 +279,97 @@ void quisk_sample_source(ty_sample_start start, ty_sample_stop stop, ty_sample_r
 	pt_sample_read = read;
 }
 
+/*!
+ * \brief Driver interface for reading samples from a device
+ * 
+ * \param dev Input. Device to read from
+ * \param cSamples Output. Read samples.
+ * \returns number of samples read
+ */
+int read_sound_interface(
+   struct sound_dev* dev,
+   complex double * cSamples
+)
+{
+   int nSamples = 0;
+   
+   // Read using correct driver.
+   switch( dev->driver )
+   {
+      case DEV_DRIVER_PORTAUDIO:
+         nSamples = quisk_read_portaudio(dev, cSamples);
+         break;
+      case DEV_DRIVER_ALSA:
+         nSamples = quisk_read_alsa(dev, cSamples);
+         break;
+      case DEV_DRIVER_PULSEAUDIO:
+         nSamples = quisk_read_pulseaudio(dev, cSamples);
+         break;
+      case DEV_DRIVER_NONE:
+      default:
+         break;
+   }
+   
+   return nSamples;
+}
+
+/*!
+ * \brief Driver interface for playing samples to a device
+ * 
+ * \param dev Input. Device to play to
+ * \param nSamples Input. Number of samples to play
+ * \param cSamples Input. Samples to play
+ * \param report_latency Input. 1 to report latency, 0 otherwise.
+ * \param volume Input. [0,1] volume ratio
+ * \returns number of samples read
+ */
+void play_sound_interface(
+   struct sound_dev* dev,
+   int nSamples,
+   complex double * cSamples,
+   int report_latency,
+   double volume
+)
+{
+   // Play using correct driver.
+   switch( dev->driver )
+   {
+      case DEV_DRIVER_PORTAUDIO:
+         quisk_play_portaudio(dev, nSamples, cSamples, report_latency, volume);
+         break;
+      case DEV_DRIVER_ALSA:
+         quisk_play_alsa(dev, nSamples, cSamples, report_latency, volume);
+         break;
+      case DEV_DRIVER_PULSEAUDIO:
+         quisk_play_pulseaudio(dev, nSamples, cSamples, report_latency, volume);
+         break;
+      case DEV_DRIVER_NONE:
+      default:
+         break;
+   }
+}
+
 int quisk_read_sound(void)	// Called from sound thread
 {  // called in an infinite loop by the main program
 	int i, nSamples, mic_count, mic_interp, retval, is_cw, mic_sample_rate;
-	complex tx_mic_phase;
+	complex double tx_mic_phase;
 	static double cwEnvelope=0;
 	static double cwCount=0;
-	static complex tuneVector = (double)CLIP32 / CLIP16;	// Convert 16-bit to 32-bit samples
+	static complex double tuneVector = (double)CLIP32 / CLIP16;	// Convert 16-bit to 32-bit samples
 	static struct quisk_cFilter filtInterp={NULL};
 #if DEBUG_MIC == 1
-	complex tmpSamples[SAMP_BUFFER_SIZE];
+	complex double tmpSamples[SAMP_BUFFER_SIZE];
 #endif
 
 	quisk_sound_state.interupts++;
 #if DEBUG_IO > 1
 	QuiskPrintTime("Start read_sound", 0);
 #endif
-	if (pt_sample_read) {			// read samples from SDR-IQ
+	if (pt_sample_read) {			// read samples from SDR-IQ or UDP
 		nSamples = (*pt_sample_read)(cSamples);
 	}
-	else if (quisk_using_udp) {	// read samples from UDP port
-		nSamples = quisk_read_rx_udp(cSamples);
-	}
 	else if (Capture.handle) {							// blocking read from soundcard
-		if (Capture.portaudio_index < 0)
-			nSamples = quisk_read_alsa(&Capture, cSamples);
-		else
-			nSamples = quisk_read_portaudio(&Capture, cSamples);
+		nSamples = read_sound_interface(&Capture, cSamples);
 		if (Capture.channel_Delay >= 0)	// delay the I or Q channel by one sample
 			delay_sample(&Capture, (double *)cSamples, nSamples);
 		if (Capture.doAmplPhase)		// amplitude and phase corrections
@@ -342,28 +406,22 @@ int quisk_read_sound(void)	// Called from sound thread
 		is_recording_samples = 0;
 	}
 	// Perhaps write samples to a loopback device for use by another program
-	if (RawSamplePlayback.handle) {
-		if (RawSamplePlayback.portaudio_index < 0)
-			quisk_play_alsa(&RawSamplePlayback, nSamples, cSamples, 0, 1.0);
-		else
-			quisk_play_portaudio(&RawSamplePlayback, nSamples, cSamples, 0, 1.0);
-	}
+	if (RawSamplePlayback.handle)
+		play_sound_interface(&RawSamplePlayback, nSamples, cSamples, 0, 1.0);
 #if ! DEBUG_MIC
 	nSamples = quisk_process_samples(cSamples, nSamples);
 #endif
 #if DEBUG_IO > 1
 	QuiskPrintTime("  process samples", 0);
 #endif
-	if (Playback.portaudio_index < 0)
-		quisk_play_alsa(&Playback, nSamples, cSamples, 1, quisk_audioVolume);
-	else
-		quisk_play_portaudio(&Playback, nSamples, cSamples, 1, quisk_audioVolume);
-	if (rxMode == 7 || rxMode == 8 || rxMode == 9) {
-		if (DigitalOutput.portaudio_index < 0)
-			quisk_play_alsa(&DigitalOutput, nSamples, cSamples, 0, digital_output_level);
-		else
-			quisk_play_portaudio(&DigitalOutput, nSamples, cSamples, 0, digital_output_level);
-	}
+   
+	// Play the demodulated audio
+	play_sound_interface(&Playback, nSamples, cSamples, 1, quisk_audioVolume);
+   
+	// Play digital if required
+	if (rxMode == 7 || rxMode == 8 || rxMode == 9)
+		play_sound_interface(&DigitalOutput, nSamples, cSamples, 0, digital_output_level);
+   
 	// Perhaps record the speaker audio to a file
 	if (want_record) {
 		if (is_recording_audio) {
@@ -385,22 +443,15 @@ int quisk_read_sound(void)	// Called from sound thread
 	// Read and process the microphone
 	mic_count = 0;
 	mic_sample_rate = quisk_sound_state.mic_sample_rate;
-	if (MicCapture.handle) {
-		if (MicCapture.portaudio_index < 0)
-			mic_count = quisk_read_alsa(&MicCapture, cSamples);
-		else
-			mic_count = quisk_read_portaudio(&MicCapture, cSamples);
-	}
+	if (MicCapture.handle)
+		mic_count = read_sound_interface(&MicCapture, cSamples);
 	if (quisk_record_state == PLAYBACK) {	// Discard previous samples and replace with saved sound
 		quisk_tmp_microphone(cSamples, mic_count);
 	}
 	if (rxMode == 7 || rxMode == 8 || rxMode == 9) {		// Discard previous samples and use digital samples
 		if (DigitalInput.handle) {
 			mic_sample_rate = DigitalInput.sample_rate;
-			if (DigitalInput.portaudio_index < 0)
-				mic_count = quisk_read_alsa(&DigitalInput, cSamples);
-			else
-				mic_count = quisk_read_portaudio(&DigitalInput, cSamples);
+			mic_count = read_sound_interface(&DigitalInput, cSamples);
 		}
 		else {
 			mic_count = 0;
@@ -445,7 +496,10 @@ int quisk_read_sound(void)	// Called from sound thread
 						if (cwEnvelope > 1.0)
 							cwEnvelope = 1.0;
 					}
-					cSamples[mic_count++] = (CLIP16 - 1) * cwEnvelope * tuneVector * quisk_sound_state.mic_out_volume;
+					if (quiskSpotLevel)
+						cSamples[mic_count++] = (CLIP16 - 1) * cwEnvelope * quiskSpotLevel / 1000.0 * tuneVector * quisk_sound_state.mic_out_volume;
+					else
+						cSamples[mic_count++] = (CLIP16 - 1) * cwEnvelope * tuneVector * quisk_sound_state.mic_out_volume;
 					tuneVector *= tx_mic_phase;
 					cwCount -= 1;
 				}
@@ -488,10 +542,7 @@ int quisk_read_sound(void)	// Called from sound thread
 		if (MicPlayback.doAmplPhase)
 			correct_sample (&MicPlayback, cSamples, mic_count);
 		// play mic samples
-		if (MicPlayback.portaudio_index < 0)
-			quisk_play_alsa(&MicPlayback, mic_count, cSamples, 0, 1.0);
-		else
-			quisk_play_portaudio(&MicPlayback, mic_count, cSamples, 0, 1.0);
+		play_sound_interface(&MicPlayback, mic_count, cSamples, 0, 1.0);
 #if DEBUG_MIC == 2
 		quisk_process_samples(cSamples, mic_count);
 #endif
@@ -515,10 +566,11 @@ int quisk_get_overrange(void)	// Called from GUI thread
 
 void quisk_close_sound(void)	// Called from sound thread
 {
-	if (pt_sample_stop)
-		(*pt_sample_stop)();
 	quisk_close_sound_portaudio();
 	quisk_close_sound_alsa(CaptureDevices, PlaybackDevices);
+	quisk_close_sound_pulseaudio(CaptureDevices, PlaybackDevices);
+	if (pt_sample_stop)
+		(*pt_sample_stop)();
 	strncpy (quisk_sound_state.err_msg, CLOSED_TEXT, QUISK_SC_SIZE);
 }
 
@@ -530,6 +582,49 @@ static void set_num_channels(struct sound_dev * dev)
 	dev->num_channels++;
 }
 
+//! \brief Returns 1 if \c string starts with \c prefix. 0 otherwise.
+int starts_with( const char* string, const char* prefix )
+{
+   size_t plen = strlen(prefix);
+   if( strlen(string) < plen )
+      return 0;
+   else
+      return strncmp( string, prefix, plen ) == 0 ? 1 : 0;
+}
+
+/*!
+ * \brief From the sound_dev.name field, decide which driver to use for which device
+ */
+void decide_drivers(
+	struct sound_dev** pDevs
+)
+{
+	const char* name;
+	// No name means no driver.
+	// If name starts with 'portaudio', it's portaudio. Else, if it starts with
+	// 'pulse', it's PulseAudio. Else, if it starts with 'alsa', it's ALSA.
+	// Otherwise, just guess ALSA.
+   
+   while(1)
+   {
+      struct sound_dev* dev = *pDevs++;
+      if( !dev )
+         break;
+      
+      name = dev->name;
+      if( ! name || name[0] == '\0' )
+         dev->driver = DEV_DRIVER_NONE;
+      else if( starts_with(name, "portaudio") )
+         dev->driver = DEV_DRIVER_PORTAUDIO;
+      else if( starts_with(name, "pulse") )
+         dev->driver = DEV_DRIVER_PULSEAUDIO;
+      else if( starts_with(name, "alsa") )
+         dev->driver = DEV_DRIVER_ALSA;
+      else
+         dev->driver = DEV_DRIVER_ALSA;
+   }
+}
+
 void quisk_open_sound(void)	// Called from GUI thread
 {
 	int i;
@@ -544,28 +639,44 @@ void quisk_open_sound(void)	// Called from GUI thread
 	quisk_sound_state.msg1[0] = 0;
 	quisk_sound_state.err_msg[0] = 0;
 
+	// Set stream names
 	strncpy(Capture.name, quisk_sound_state.dev_capt_name, QUISK_SC_SIZE);
 	strncpy(Playback.name, quisk_sound_state.dev_play_name, QUISK_SC_SIZE);
 	strncpy(MicCapture.name, quisk_sound_state.mic_dev_name, QUISK_SC_SIZE);
 	strncpy(MicPlayback.name, quisk_sound_state.name_of_mic_play, QUISK_SC_SIZE);
+	strncpy(DigitalInput.name, QuiskGetConfigString ("digital_input_name", ""), QUISK_SC_SIZE);
+	strncpy(DigitalOutput.name, QuiskGetConfigString ("digital_output_name", ""), QUISK_SC_SIZE);
+	strncpy(RawSamplePlayback.name, QuiskGetConfigString ("sample_playback_name", ""), QUISK_SC_SIZE);
+   
+	// Set stream descriptions. This is important for "deviceless" drivers like
+	// PulseAudio to be able to distinguish the streams from each other.
+	strncpy(Capture.stream_description, "IQ Input", QUISK_SC_SIZE);
+	Capture.stream_description[QUISK_SC_SIZE-1] = '\0';
+	strncpy(Playback.stream_description, "Radio Audio Output", QUISK_SC_SIZE);
+	Playback.stream_description[QUISK_SC_SIZE-1] = '\0';
+	strncpy(MicCapture.stream_description, "Microphone Input", QUISK_SC_SIZE);
+	MicCapture.stream_description[QUISK_SC_SIZE-1] = '\0';
+	strncpy(MicPlayback.stream_description, "IQ Output", QUISK_SC_SIZE);
+	MicPlayback.stream_description[QUISK_SC_SIZE-1] = '\0';
+	strncpy(DigitalInput.stream_description, "Digital Input", QUISK_SC_SIZE);
+	strncpy(DigitalOutput.stream_description, "Digital Output", QUISK_SC_SIZE);
+	strncpy(RawSamplePlayback.stream_description, "Raw Sample output", QUISK_SC_SIZE);
+   
 	Playback.sample_rate = quisk_sound_state.playback_rate;		// Radio sound play rate
 	MicPlayback.sample_rate = quisk_sound_state.mic_playback_rate;
 	MicCapture.sample_rate = quisk_sound_state.mic_sample_rate;
 	MicCapture.channel_I = quisk_sound_state.mic_channel_I;	// Mic audio is here
 	MicCapture.channel_Q = quisk_sound_state.mic_channel_Q;
 	// Capture device for digital modes
-	strncpy(DigitalInput.name, QuiskGetConfigString ("digital_input_name", ""), QUISK_SC_SIZE);
 	DigitalInput.sample_rate = 48000;
 	DigitalInput.channel_I = 0;
 	DigitalInput.channel_Q = 1;
 	// Playback device for digital modes
-	strncpy(DigitalOutput.name, QuiskGetConfigString ("digital_output_name", ""), QUISK_SC_SIZE);
 	digital_output_level = QuiskGetConfigDouble("digital_output_level", 0.7);
 	DigitalOutput.sample_rate = quisk_sound_state.playback_rate;	// Radio sound play rate
 	DigitalOutput.channel_I = 0;
 	DigitalOutput.channel_Q = 1;
 	// Playback device for raw samples
-	strncpy(RawSamplePlayback.name, QuiskGetConfigString ("sample_playback_name", ""), QUISK_SC_SIZE);
 	RawSamplePlayback.sample_rate = quisk_sound_state.sample_rate;
 	RawSamplePlayback.channel_I = 0;
 	RawSamplePlayback.channel_Q = 1;
@@ -585,15 +696,10 @@ void quisk_open_sound(void)	// Called from GUI thread
 #endif
 	MicPlayback.channel_Delay = QuiskGetConfigInt ("tx_channel_delay", -1);
 
-	if (pt_sample_read) {		// capture from SDR-IQ by Rf-Space
+	if (pt_sample_read)			// capture from SDR-IQ by Rf-Space or UDP
 		Capture.name[0] = 0;	// zero the capture soundcard name
-	}
-	else if (quisk_using_udp) {	// samples from UDP at multiple of 48 kHz
-		Capture.name[0] = 0;		// zero the capture soundcard name
-	}
-	else {		// sound card capture
+	else						// sound card capture
 		Capture.sample_rate = quisk_sound_state.sample_rate;
-	}
 	// set read size for sound card capture
 	i = (int)(quisk_sound_state.data_poll_usec * 1e-6 * Capture.sample_rate + 0.5);
 	i = i / 64 * 64;
@@ -625,15 +731,23 @@ void quisk_start_sound(void)	// Called from sound thread
 {
 	if (pt_sample_start)
 		(*pt_sample_start)();
+   
+	// Decide which drivers start which devices.
+	decide_drivers(CaptureDevices);
+	decide_drivers(PlaybackDevices);
+   
+	// Let the drivers see the devices and start them up if appropriate
 	quisk_start_sound_portaudio(CaptureDevices, PlaybackDevices);
+	quisk_start_sound_pulseaudio(CaptureDevices, PlaybackDevices);
 	quisk_start_sound_alsa(CaptureDevices, PlaybackDevices);
-	if (pt_sample_read || quisk_using_udp) {
+   
+	if (pt_sample_read) {	// Capture from SDR-IQ or UDP
 		quisk_sound_state.rate_min = Playback.rate_min;
 		quisk_sound_state.rate_max = Playback.rate_max;
 		quisk_sound_state.chan_min = Playback.chan_min;
 		quisk_sound_state.chan_max = Playback.chan_max;
 	}
-	else {
+	else {					// Capture from sound card
 		quisk_sound_state.rate_min = Capture.rate_min;
 		quisk_sound_state.rate_max = Capture.rate_max;
 		quisk_sound_state.chan_min = Capture.chan_min;
