@@ -24,7 +24,7 @@ static unsigned char buffer3[3 * SAMP_BUFFER_SIZE];	// Buffer for 3-byte samples
 static int buffer4[SAMP_BUFFER_SIZE];				// Buffer for 4-byte samples from sound
 static int bufferz[SAMP_BUFFER_SIZE];				// Buffer for zero samples
 
-int quisk_read_alsa(struct sound_dev * dev, complex * cSamples)
+int quisk_read_alsa(struct sound_dev * dev, complex double * cSamples)
 {	// Read sound samples from the ALSA soundcard.
 	// Samples are converted to 32 bits with a range of +/- CLIP32 and placed into cSamples.
 	int i;
@@ -32,7 +32,7 @@ int quisk_read_alsa(struct sound_dev * dev, complex * cSamples)
 	short si, sq;
 	int ii, qq;
 	int nSamples;
-	complex c;
+	complex double c;
 
 	if (!dev->handle)
 		return -1;
@@ -163,7 +163,7 @@ int quisk_read_alsa(struct sound_dev * dev, complex * cSamples)
 }
 
 void quisk_play_alsa(struct sound_dev * playdev, int nSamples,
-		complex * cSamples, int report_latency, double volume)
+		complex double * cSamples, int report_latency, double volume)
 {	// Play the samples; write them to the ALSA soundcard.
 	int i, n, index;
 	snd_pcm_sframes_t frames, delay;
@@ -535,6 +535,7 @@ static int quisk_open_alsa_capture(struct sound_dev * dev)
 		return 1;
 	}
 	dev->handle = handle;
+	dev->driver = DEV_DRIVER_ALSA;
 	if ((err = snd_pcm_sw_params_malloc (&sware)) < 0) {
 		snprintf (quisk_sound_state.err_msg, QUISK_SC_SIZE, "Cannot allocate software parameter structure (%s)\n",
 				snd_strerror (err));
@@ -660,8 +661,10 @@ static int quisk_open_alsa_playback(struct sound_dev * dev)
 
 	if ( ! dev->name[0])	// Check for null play name
 		return 0;
+
 #if DEBUG_IO
-    printf("*** Playback on alsa device %s\n", dev->name);
+	printf("*** Playback on alsa device %s\n", dev->name);
+	printf("quisk_open_alsa_playback(): %s\n", dev->stream_description);
 #endif
 	if ( ! strncmp (dev->name, "alsa:", 5)) {	// search for the name in info strings
 		char buf[QUISK_SC_SIZE];
@@ -818,7 +821,7 @@ void quisk_start_sound_alsa (struct sound_dev ** pCapture, struct sound_dev ** p
 		pDev = *pPlayback++;
 		if ( ! pDev)
 			break;
-		if ( ! pDev->handle && pDev->portaudio_index < 0)
+		if ( ! pDev->handle && pDev->driver == DEV_DRIVER_ALSA)
 			if (quisk_open_alsa_playback(pDev))
 				return;		// error
 	}
@@ -827,7 +830,7 @@ void quisk_start_sound_alsa (struct sound_dev ** pCapture, struct sound_dev ** p
 		pDev = *pCapture++;
 		if ( ! pDev)
 			break;
-		if ( ! pDev->handle && pDev->portaudio_index < 0) {
+		if ( ! pDev->handle && pDev->driver == DEV_DRIVER_ALSA) {
 			if (quisk_open_alsa_capture(pDev))
 				return;		// error
 			if (pDev->handle)
@@ -842,20 +845,22 @@ void quisk_close_sound_alsa(struct sound_dev ** pCapture, struct sound_dev ** pP
 
 	while (*pCapture) {
 		pDev = *pCapture;
-		if (pDev->handle && pDev->portaudio_index < 0) {
+		if (pDev->handle && pDev->driver == DEV_DRIVER_ALSA) {
 			snd_pcm_drop((snd_pcm_t *)pDev->handle);
 			snd_pcm_close((snd_pcm_t *)pDev->handle);
 		}
 		pDev->handle = NULL;
+		pDev->driver = DEV_DRIVER_NONE;
 		pCapture++;
 	}
 	while (*pPlayback) {
 		pDev = *pPlayback;
-		if (pDev->handle && pDev->portaudio_index < 0) {
+		if (pDev->handle && pDev->driver == DEV_DRIVER_ALSA) {
 			snd_pcm_drop((snd_pcm_t *)pDev->handle);
 			snd_pcm_close((snd_pcm_t *)pDev->handle);
 		}
 		pDev->handle = NULL;
+		pDev->driver = DEV_DRIVER_NONE;
 		pPlayback++;
 	}
 }
