@@ -255,13 +255,6 @@ void quisk_close_sound_alsa(struct sound_dev ** pCapture, struct sound_dev ** pP
 {
 	struct sound_dev * pDev;
 
-	while (*pCapture) {
-		pDev = *pCapture;
-		if (pDev->buffer)
-			IDirectSoundCaptureBuffer_Stop((LPDIRECTSOUNDCAPTUREBUFFER)pDev->buffer);
-		pDev->handle = NULL;
-		pCapture++;
-	}
 	while (*pPlayback) {
 		pDev = *pPlayback;
 		if (pDev->buffer)
@@ -269,10 +262,17 @@ void quisk_close_sound_alsa(struct sound_dev ** pCapture, struct sound_dev ** pP
 		pDev->handle = NULL;
 		pPlayback++;
 	}
+	while (*pCapture) {
+		pDev = *pCapture;
+		if (pDev->buffer)
+			IDirectSoundCaptureBuffer_Stop((LPDIRECTSOUNDCAPTUREBUFFER)pDev->buffer);
+		pDev->handle = NULL;
+		pCapture++;
+	}
 }
 
 
-int  quisk_read_alsa(struct sound_dev * dev, complex * cSamples)
+int  quisk_read_alsa(struct sound_dev * dev, complex double * cSamples)
 {
 	LPDIRECTSOUNDCAPTUREBUFFER ptBuf = (LPDIRECTSOUNDCAPTUREBUFFER)dev->buffer;
 	HRESULT hr;
@@ -282,7 +282,7 @@ int  quisk_read_alsa(struct sound_dev * dev, complex * cSamples)
 	short si, sq, * pts;
 	float fi, fq, * ptf;
 	int   li, lq, * ptl;	// int must be 32 bits
-	complex c;
+	complex double c;
 	int ii, qq, nSamples;
 	int bytes, frames, poll_size, millisecs, bytes_per_frame, pass;
 	
@@ -429,7 +429,7 @@ int  quisk_read_alsa(struct sound_dev * dev, complex * cSamples)
 }
 
 void quisk_play_alsa(struct sound_dev * dev, int nSamples,
-		complex * cSamples, int report_latency, double volume)
+		complex double * cSamples, int report_latency, double volume)
 {
 	LPDIRECTSOUNDBUFFER ptBuf = (LPDIRECTSOUNDBUFFER)dev->buffer;
 	DWORD playPos, writePos;	// hardware index into buffer
@@ -585,7 +585,7 @@ void quisk_play_alsa(struct sound_dev * dev, int nSamples,
 
 
 
-void quisk_play_portaudio(struct sound_dev * dev, int j, complex * samp, int i, double volume)
+void quisk_play_portaudio(struct sound_dev * dev, int j, complex double * samp, int i, double volume)
 {
 }
 
@@ -597,11 +597,28 @@ void quisk_close_sound_portaudio(void)
 {
 }
 
-int  quisk_read_portaudio(struct sound_dev * dev, complex * samp)
+int  quisk_read_portaudio(struct sound_dev * dev, complex double * samp)
 {
 	return 0;
 }
 
+int  quisk_read_pulseaudio(struct sound_dev * dev, complex double * samp)
+{
+	return 0;
+}
+
+void quisk_play_pulseaudio(struct sound_dev * dev, int j, complex double * samp, int i, double volume)
+{
+}
+
+void quisk_start_sound_pulseaudio(struct sound_dev ** pCapture, struct sound_dev ** pPlayback)
+{
+}
+
+void quisk_close_sound_pulseaudio(struct sound_dev ** pCapture, struct sound_dev ** pPlayback)
+{
+}
+
 void quisk_mixer_set(char * card_name, int numid, PyObject * value, char * err_msg, int err_size)
 {
 	err_msg[0] = 0;
